@@ -1,40 +1,42 @@
-import typing as t
+from typing import Any, Dict, Iterable, Mapping, Optional, Type, Union
 
 import marshmallow as ma
 import peewee as pw
 
+from . import DEFAULTS
 from .convert import ModelConverter
 from .fields import Related
 
 
 class SchemaOpts(ma.SchemaOpts):
 
-    model: t.Optional[pw.Model]
+    model: Optional[Type[pw.Model]]
     dump_only_pk: bool
     string_keys: bool
+    id_keys: bool
 
     def __init__(self, meta, **kwargs):
         super(SchemaOpts, self).__init__(meta, **kwargs)
-        self.model = getattr(meta, 'model', None)
-        self.dump_only_pk = getattr(meta, 'dump_only_pk', True)
-        self.string_keys = getattr(meta, 'string_keys', True)
+        self.model = getattr(meta, "model", None)
+        self.dump_only_pk = getattr(meta, "dump_only_pk", DEFAULTS["dump_only_pk"])
+        self.string_keys = getattr(meta, "string_keys", DEFAULTS["string_keys"])
+        self.id_keys = getattr(meta, "id_keys", DEFAULTS["id_keys"])
 
         if self.model and not issubclass(self.model, pw.Model):
             raise ValueError("`model` must be a subclass of peewee.Model")
 
-        self.model_converter = getattr(meta, 'model_converter', ModelConverter)
+        self.model_converter = getattr(meta, "model_converter", ModelConverter)
 
 
-INHERITANCE_OPTIONS = 'model', 'model_converter', 'dump_only_pk', 'string_keys'
+INHERITANCE_OPTIONS = "model", "model_converter", "dump_only_pk", "string_keys"
 
 
 class SchemaMeta(ma.schema.SchemaMeta):
-
     def __new__(mcs, name, bases, attrs):
         """Support inheritance for model and model_converter Meta options."""
-        if 'Meta' in attrs and bases:
-            meta = attrs['Meta']
-            base_meta = getattr(bases[0], 'Meta', None)
+        if "Meta" in attrs and bases:
+            meta = attrs["Meta"]
+            base_meta = getattr(bases[0], "Meta", None)
             for option in INHERITANCE_OPTIONS:
                 if hasattr(meta, option) or not hasattr(base_meta, option):
                     continue
@@ -49,7 +51,7 @@ class SchemaMeta(ma.schema.SchemaMeta):
         base_fields = super(SchemaMeta, mcs).get_declared_fields(
             klass, cls_fields, inherited_fields, dict_cls
         )
-        model = getattr(opts, 'model', None)
+        model = getattr(opts, "model", None)
         if model:
             for name, field in base_fields.items():
                 if isinstance(field, Related) and field.nested is None:
@@ -72,7 +74,7 @@ class ModelSchema(ma.Schema, metaclass=SchemaMeta):
         super(ModelSchema, self).__init__(**kwargs)
 
     @ma.post_load
-    def make_instance(self, data: t.Dict, **kwargs) -> t.Union[t.Dict, pw.Model]:
+    def make_instance(self, data: Dict, **_) -> Union[Dict, pw.Model]:
         """Build object from data."""
         if not self.opts.model:
             return data
@@ -84,7 +86,12 @@ class ModelSchema(ma.Schema, metaclass=SchemaMeta):
 
         return self.opts.model(**data)
 
-    def load(self, data: t.Union[t.Mapping[str, t.Any], t.Iterable[t.Mapping[str, t.Any]]],
-             instance: pw.Model = None, *args, **kwargs):
+    def load(
+        self,
+        data: Union[Mapping[str, Any], Iterable[Mapping[str, Any]]],
+        instance: pw.Model = None,
+        *args,
+        **kwargs
+    ):
         self.instance = instance or self.instance
         return super(ModelSchema, self).load(data, *args, **kwargs)
